summaryrefslogtreecommitdiffstats
path: root/base
diff options
context:
space:
mode:
authormark@chromium.org <mark@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-29 18:59:13 +0000
committermark@chromium.org <mark@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-29 18:59:13 +0000
commit0f64c1daccfc82eab19ad7ed1fb9d5a381ac8875 (patch)
treec209c1672a2e0d73cef0d8f91836981ffc17d31c /base
parent8dfa2d9cd1f3aee9ec5df6734e7f57c755c4cc09 (diff)
downloadchromium_src-0f64c1daccfc82eab19ad7ed1fb9d5a381ac8875.zip
chromium_src-0f64c1daccfc82eab19ad7ed1fb9d5a381ac8875.tar.gz
chromium_src-0f64c1daccfc82eab19ad7ed1fb9d5a381ac8875.tar.bz2
Back out r77530, making the helper app an LSUIElement as it had been prior to
that revision. LSBackgroundOnly didn't actually prevent the helper app from creating UI, but it did prevent it from bringing windows to the foreground. This resulted in a poor experieince with plugins presenting, for example, file open/save dialogs. BUG=none TEST=Flash-based attachment uploader in Gmail should show standard file open dialog in the foreground when "Attach a file" is selected. There should only be one Chrome icon in the dock while Chrome is running. Review URL: http://codereview.chromium.org/6771019 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@79711 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base')
-rw-r--r--base/mac/foundation_util.mm4
1 files changed, 2 insertions, 2 deletions
diff --git a/base/mac/foundation_util.mm b/base/mac/foundation_util.mm
index 146f2ca..3f41466 100644
--- a/base/mac/foundation_util.mm
+++ b/base/mac/foundation_util.mm
@@ -60,10 +60,10 @@ void SetOverrideAmIBundled(bool value) {
bool IsBackgroundOnlyProcess() {
// This function really does want to examine NSBundle's idea of the main
// bundle dictionary, and not the overriden MainAppBundle. It needs to look
// at the actual running .app's Info.plist to access its LSBackgroundOnly
// property.
NSDictionary* info_dictionary = [[NSBundle mainBundle] infoDictionary];
- return [[info_dictionary objectForKey:@"LSBackgroundOnly"] boolValue] != NO;
+ return [[info_dictionary objectForKey:@"LSUIElement"] boolValue] != NO;
}
// No threading worries since NSBundle isn't thread safe.
@@ -60,10 +60,10 @@ void SetOverrideAmIBundled(bool value) {
// This function really does want to examine NSBundle's idea of the main
// bundle dictionary, and not the overriden MainAppBundle. It needs to look
- // at the actual running .app's Info.plist to access its LSBackgroundOnly
+ // at the actual running .app's Info.plist to access its LSUIElement
// property.
NSDictionary* info_dictionary = [[NSBundle mainBundle] infoDictionary];